==> pipewire-docs-1%3A0.3.70-2-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__pw__properties.js <==
var group__pw__properties =
[
    [ "properties.h", "properties_8h.html", null ],
    [ "pw_properties", "structpw__properties.html", [
      [ "dict", "structpw__properties.html#a70aa5816bde60f5511f2308971794881", null ],
      [ "flags", "structpw__properties.html#a8003e978689f764bb7bd2a3ab2d46a87", null ]
    ] ],
    [ "PW_PROPERTIES_FLAG_NL", "group__pw__properties.html#gab1c1ac34b138a20ee21b5b4647dfe24a", null ],
    [ "PW_PROPERTIES_FLAG_RECURSE", "group__pw__properties.html#gad81dddbf98b681b6e9d672041782c5f3", null ],
    [ "PW_PROPERTIES_FLAG_ENCLOSE", "group__pw__properties.html#ga51237cc8ccfa0a84a7df25800e962731", null ],
    [ "PW_PROPERTIES_FLAG_ARRAY", "group__pw__properties.html#ga8a98fcda5b4eb3d7aeb0daaacefc9b6c", null ],
    [ "PW_PROPERTIES_FLAG_COLORS", "group__pw__properties.html#gaad20740b131f615b1c143a06f15ef976", null ],
    [ "pw_properties_new", "group__pw__properties.html#ga1b4b83cd7ff56bdcabc3419f3a40eb95", null ],
    [ "pw_properties_new_dict", "group__pw__properties.html#ga5430d66a13acaee2e5bac67d32e48c73", null ],
    [ "pw_properties_new_string", "group__pw__properties.html#ga7bedc63c78dfe152e866dc518424f299", null ],
    [ "pw_properties_copy", "group__pw__properties.html#gaef2c92377eef51a7cb6d7116be7a4f17", null ],
    [ "pw_properties_update_keys", "group__pw__properties.html#gaada5fb228c3337d5016e63a99fc867ee", null ],
    [ "pw_properties_update_ignore", "group__pw__properties.html#ga43d166937b32ebb05bae40ab4a71e124", null ],
    [ "pw_properties_update", "group__pw__properties.html#ga4d64a233d0ff9e8f1fbab721948fbdca", null ],
    [ "pw_properties_update_string", "group__pw__properties.html#ga257901a94fbb454f294fef45ebe9e084", null ],
    [ "pw_properties_add", "group__pw__properties.html#ga375f258e0fd46fb55233eeb0280ef5d5", null ],
    [ "pw_properties_add_keys", "group__pw__properties.html#gad92242e1aca2b6bbff111631e342db72", null ],
    [ "pw_properties_clear", "group__pw__properties.html#gabe3bcabf87a8e0dc65fb9abb5ea60961", null ],
    [ "pw_properties_free", "group__pw__properties.html#ga020d2bd083e845bbfa3d2366d8c7ffec", null ],
    [ "pw_properties_set", "group__pw__properties.html#ga8ef83913ccf2abb4432ba0ebd3230516", null ],
    [ "pw_properties_setf", "group__pw__properties.html#ga4728814e214495beebb185fc67ca902e", null ],
    [ "pw_properties_setva", "group__pw__properties.html#gad3c5eb05f64310402534a212810e4f7b", null ],
    [ "pw_properties_get", "group__pw__properties.html#ga3cd67f2df69f8edce9cfdb05b8bddf9f", null ],
    [ "pw_properties_fetch_uint32", "group__pw__properties.html#gacbd80e7c6313b831fa0f8617ccf1b54d", null ],
    [ "pw_properties_fetch_int32", "group__pw__properties.html#gaff88f004cda9f9187224460ca54d3785", null ],
    [ "pw_properties_fetch_uint64", "group__pw__properties.html#ga6807c59e72e0784a598cddc9c8a18ec7", null ],
    [ "pw_properties_fetch_int64", "group__pw__properties.html#gab091b12b4aea7ead4e9c5577f1d77582", null ],
    [ "pw_properties_fetch_bool", "group__pw__properties.html#ga429e3c094a41c58b4db1914833c1e5f8", null ],
    [ "pw_properties_get_uint32", "group__pw__properties.html#gadb46a9d4719f6c276827ceae6f8c1e38", null ],
    [ "pw_properties_get_int32", "group__pw__properties.html#gaa8c551ab454f6adbc0c591ec584fa97a", null ],
    [ "pw_properties_get_uint64", "group__pw__properties.html#ga88e954267fa14f49b4b7b924a0022304", null ],
    [ "pw_properties_get_int64", "group__pw__properties.html#ga92252cdd9981c531a5f71191a6348925", null ],
    [ "pw_properties_get_bool", "group__pw__properties.html#ga294aef7f4ff508176b72292effb30ac8", null ],
    [ "pw_properties_iterate", "group__pw__properties.html#ga5166f331d0f37ef4d6c40de5b09a30ca", null ],
    [ "pw_properties_serialize_dict", "group__pw__properties.html#gaf56f609986cd8b84c6b0f25fd6c3835d", null ],
    [ "pw_properties_parse_bool", "group__pw__properties.html#ga3dbe2029efc42ed8ff931bf732ad6c07", null ],
    [ "pw_properties_parse_int", "group__pw__properties.html#ga2fe1f2d6247e6a594bded10f2281e972", null ],
    [ "pw_properties_parse_int64", "group__pw__properties.html#ga2a74f501f08394c09018d9c29450f2f4", null ],
    [ "pw_properties_parse_uint64", "group__pw__properties.html#gabe301c4380716c6bfefbd21a46e13cb5", null ],
    [ "pw_properties_parse_float", "group__pw__properties.html#ga791e01f0afa028ebb1531114c0d0cbe2", null ],
    [ "pw_properties_parse_double", "group__pw__properties.html#gac297ab99052273cca88017445ec77cc0", null ]
];

==> pipewire-docs-1%3A1.2.7-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__pw__properties.js <==
var group__pw__properties =
[
    [ "properties.h", "properties_8h.html", null ],
    [ "pw_properties", "structpw__properties.html", [
      [ "dict", "structpw__properties.html#a70aa5816bde60f5511f2308971794881", null ],
      [ "flags", "structpw__properties.html#a8003e978689f764bb7bd2a3ab2d46a87", null ]
    ] ],
    [ "PW_PROPERTIES_FLAG_NL", "group__pw__properties.html#gab1c1ac34b138a20ee21b5b4647dfe24a", null ],
    [ "PW_PROPERTIES_FLAG_RECURSE", "group__pw__properties.html#gad81dddbf98b681b6e9d672041782c5f3", null ],
    [ "PW_PROPERTIES_FLAG_ENCLOSE", "group__pw__properties.html#ga51237cc8ccfa0a84a7df25800e962731", null ],
    [ "PW_PROPERTIES_FLAG_ARRAY", "group__pw__properties.html#ga8a98fcda5b4eb3d7aeb0daaacefc9b6c", null ],
    [ "PW_PROPERTIES_FLAG_COLORS", "group__pw__properties.html#gaad20740b131f615b1c143a06f15ef976", null ],
    [ "pw_properties_new", "group__pw__properties.html#ga1a1bbd65fb0ad25e5a3e5d120f6db3ec", null ],
    [ "pw_properties_new_dict", "group__pw__properties.html#ga5430d66a13acaee2e5bac67d32e48c73", null ],
    [ "pw_properties_new_string", "group__pw__properties.html#ga7bedc63c78dfe152e866dc518424f299", null ],
    [ "pw_properties_new_string_checked", "group__pw__properties.html#gaf1afafa583d7e7a97a4a35f7a75763c6", null ],
    [ "pw_properties_copy", "group__pw__properties.html#gaef2c92377eef51a7cb6d7116be7a4f17", null ],
    [ "pw_properties_update_keys", "group__pw__properties.html#gaada5fb228c3337d5016e63a99fc867ee", null ],
    [ "pw_properties_update_ignore", "group__pw__properties.html#ga43d166937b32ebb05bae40ab4a71e124", null ],
    [ "pw_properties_update", "group__pw__properties.html#ga4d64a233d0ff9e8f1fbab721948fbdca", null ],
    [ "pw_properties_update_string", "group__pw__properties.html#ga257901a94fbb454f294fef45ebe9e084", null ],
    [ "pw_properties_update_string_checked", "group__pw__properties.html#gad57e7dc3b6a1b3672752036bd221a06e", null ],
    [ "pw_properties_add", "group__pw__properties.html#ga375f258e0fd46fb55233eeb0280ef5d5", null ],
    [ "pw_properties_add_keys", "group__pw__properties.html#gad92242e1aca2b6bbff111631e342db72", null ],
    [ "pw_properties_clear", "group__pw__properties.html#gabe3bcabf87a8e0dc65fb9abb5ea60961", null ],
    [ "pw_properties_free", "group__pw__properties.html#ga020d2bd083e845bbfa3d2366d8c7ffec", null ],
    [ "pw_properties_set", "group__pw__properties.html#ga8ef83913ccf2abb4432ba0ebd3230516", null ],
    [ "pw_properties_setf", "group__pw__properties.html#ga6ee2d4c053dbc12d412579a12f1ab3ec", null ],
    [ "pw_properties_setva", "group__pw__properties.html#gad8d80cf27adf219c5f3fa399b103eb34", null ],
    [ "pw_properties_get", "group__pw__properties.html#ga7b930604ce053325c923e07ed62a1a1c", null ],
    [ "pw_properties_fetch_uint32", "group__pw__properties.html#gacbd80e7c6313b831fa0f8617ccf1b54d", null ],
    [ "pw_properties_fetch_int32", "group__pw__properties.html#gaff88f004cda9f9187224460ca54d3785", null ],
    [ "pw_properties_fetch_uint64", "group__pw__properties.html#ga6807c59e72e0784a598cddc9c8a18ec7", null ],
    [ "pw_properties_fetch_int64", "group__pw__properties.html#gab091b12b4aea7ead4e9c5577f1d77582", null ],
    [ "pw_properties_fetch_bool", "group__pw__properties.html#ga429e3c094a41c58b4db1914833c1e5f8", null ],
    [ "pw_properties_get_uint32", "group__pw__properties.html#gadb46a9d4719f6c276827ceae6f8c1e38", null ],
    [ "pw_properties_get_int32", "group__pw__properties.html#gaa8c551ab454f6adbc0c591ec584fa97a", null ],
    [ "pw_properties_get_uint64", "group__pw__properties.html#ga88e954267fa14f49b4b7b924a0022304", null ],
    [ "pw_properties_get_int64", "group__pw__properties.html#ga92252cdd9981c531a5f71191a6348925", null ],
    [ "pw_properties_get_bool", "group__pw__properties.html#ga294aef7f4ff508176b72292effb30ac8", null ],
    [ "pw_properties_iterate", "group__pw__properties.html#ga5166f331d0f37ef4d6c40de5b09a30ca", null ],
    [ "pw_properties_serialize_dict", "group__pw__properties.html#gaf56f609986cd8b84c6b0f25fd6c3835d", null ],
    [ "pw_properties_parse_bool", "group__pw__properties.html#ga3dbe2029efc42ed8ff931bf732ad6c07", null ],
    [ "pw_properties_parse_int", "group__pw__properties.html#ga2fe1f2d6247e6a594bded10f2281e972", null ],
    [ "pw_properties_parse_int64", "group__pw__properties.html#ga2a74f501f08394c09018d9c29450f2f4", null ],
    [ "pw_properties_parse_uint64", "group__pw__properties.html#gabe301c4380716c6bfefbd21a46e13cb5", null ],
    [ "pw_properties_parse_float", "group__pw__properties.html#ga791e01f0afa028ebb1531114c0d0cbe2", null ],
    [ "pw_properties_parse_double", "group__pw__properties.html#gac297ab99052273cca88017445ec77cc0", null ]
];
